package
Version:
v0.0.0-...-53399b3
Opens a new window with list of versions in this module.
Published: Aug 5, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BaseReq struct {
Database string `json:"database,omitempty"`
Q string `json:"q,omitempty"`
}
type IndexReq struct {
ID uint32 `json:"id"`
Text string `json:"text"`
Document map[string]interface{} `json:"document"`
BaseReq
}
type QueryReq struct {
Query string `json:"query"`
Page int `json:"page"`
Limit int `json:"limit"`
Order string `json:"order"`
ScoreExp string `json:"scoreExp,omitempty"`
Highlight struct {
PreTag string `json:"preTag"`
PostTag string `json:"postTag"`
} `json:"highlight,omitempty"`
BaseReq
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.